@@ -25,7 +25,7 @@ Usage::
     list_revision_assets_paginator: ListRevisionAssetsPaginator = client.get_paginator("list_revision_assets")
     ```
 """
-from mypy_boto3_dataexchange.client import DataExchangeClient, DataExchangeClient as Client
+from mypy_boto3_dataexchange.client import DataExchangeClient
 from mypy_boto3_dataexchange.paginator import (
     ListDataSetRevisionsPaginator,
     ListDataSetsPaginator,
@@ -33,6 +33,8 @@ from mypy_boto3_dataexchange.paginator import (
     ListRevisionAssetsPaginator,
 )
 
+Client = DataExchangeClient
+
 
 __all__ = (
     "Client",
